;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 1Aw_200
;                     Accendere un LED collegato al pin GP0.
;                     Il LED si accende all' arrivo della tensione
;                     di alimentazione e rimane acceso finch questa
;                      presente

;    PIC           :  10F200/2
;    Supporto      :  MPASM
;    Versione      :  1.0
;    Data          :  01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;
;  Impiego pin :
;  ----------------
;       10F200/202 @ 8 pin DIP
;
;                  |\/|
;              NC -|1    8|- GP3
;             Vdd -|2    7|- Vss
;             GP2 -|3    6|- NC
;             GP1 -|4    5|- GP0
;                  |______|
;
;       10F200/202 @ 6 pin SOT-23
;
;                  *|
;             GP0 -|1    6|- GP3
;             Vss -|2    5|- Vdd
;             GP1 -|3    4|- GP2
;                  |______|
;
;                       DIP  SOT
;    NC                  1:     nc
;    Vdd                 2:  5: ++
;    GP2/T0CKI/FOSC4     3:  4:
;    GP1/ICSPCLK         4:  3:
;    GP0/ICSPDAT         5:  1: Out LED alla Vss
;    NC                  6:     nc
;    Vss                 7:  2: --
;    GP3/MCLR/VPP        8:  6:
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;GPIO map
; |  3  |  2  |  1  |  0  |
; |-----|-----|-----|-----|
; | in  |     |     | LED |
;
#define   LED  GPIO,GP0    ; LED tra pin e Vss
;#define       GPIO,GP1    ;
;#define       GPIO,GP2    ;
;#define       GPIO,GP3    ; solo input
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################
 #ifdef __10F200
        LIST      p=10F200     ; definizione del processore
        #include <p10F200.inc>
 #endif
 #ifdef __10F202
        LIST      p=10F202     ; definizione del processore
        #include <p10F202.inc>
 #endif

        radix     dec          ; default numeri decimali

        LIST      X = ON       ; abilta espansione macro

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; No WDT, no CP, pin4=GP3
  __config  _CP_OFF & _MCLRE_OFF  & _WDT_OFF

;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
 Accendi_LED   MACRO
        bsf     LED
               ENDM

;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; Reset Vector
RESET_VECTOR   ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni al reset
        clrf    GPIO            ; preset GPIO latch a 0

; TRISGPIO        -------0     GP0 out
        movlw   b'11111110'
        tris    GPIO            ; al registro direzione

; accende LED
        Accendi_LED

; blocco
        goto    $

;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
        END

 PAGE
;********************************************************************
; ===================================================================
; =                        DOCUMENTAZIONE                           =
;====================================================================
;********************************************************************
; Opzioni CONFIG
;
; Protezione del programma
; -------------------------
;_CP_ON                 protezione abilitata
;_CP_OFF                protezione disabilitata

; Pin MCLR
; ---------
;_MCLRE_ON              GP3/MCLR come MCLR;
;_MCLRE_OFF             GP3/MCLR come GP3

; Watchdog
; ---------
;_WDT_ON                abilitato
;_WDT_OFF               disabilitato
;_WDTE_ON               alias
;_WDTE_OFF

; Internal Oscillator
; --------------------
;_OSC_IntRC             opzione unica - non occorre dichiarare
;_IntRC_OSC             alias

;********************************************************************
;                        PRINCIPALI SFR                             *
;********************************************************************
; SFR senza banchi
;
; Esempio di maschera di inizializzazione e
; descrizione sintetica dei registri
;
;OPTION_REG - Wake pull-up & TIMER0
;-----------------------------------
; al POR          '11111111'
OPTIONVAL   EQU  B'11010111'
        ;          1-------     GPWU disabilitato
        ;          -1------     GPPU disabilitato
        ;          --0-----     clock interno
        ;          ---1----     done
        ;          ----0---     prescaler al timer
        ;          -----111     1:256
;
        ; NOT_GPWU  b7 : enable wake-up pin on change
        ;                1= disabilitato
        ;                0= abilitato
        ; NOT_GPPU  b6 : Enable Weak Pull-ups bit
        ;                1= disabilitato
        ;                0= abilitato
        ; TOCS      b5 : 1= clock TMR0 esterno da GP2
        ;                0= clock interno
        ; TOSE      b4 : 1= GP2 fronte discendente (b5=1)
        ;                0= GP2 fronte in salita   (b5=1)
        ; PSA       b3 : 1= predivisore al Watchdog
        ;                0= predivisore a TMR0
        ; PS2/PS0   b2/b0 valore del predivisore
        ;                  Watchdog   Timer0
        ;           000 =  1/1        1/2
        ;           001 =  1/2        1/4
        ;           010 =  1/4        1/8
        ;           011 =  1/8        1/16
        ;           100 =  1/16       1/32
        ;           101 =  1/32       1/64
        ;           110 =  1/64       1/128
        ;           111 =  1/128      1/256


; OSCCAL - Calibrazione oscillatore interno
; ------------------------------------------
; al POR           '11111110'
OSCCALDEF  EQU    B'00000000' ; valore intermedio

        ; CAL6:0    b7-1  : 0111111 = Maximum frequency
        ;                   0000000 = Center frequency
        ;                   1000000 = Minimum frequency
        ; FOSC4     b0    : 1= INTOSC/4 su GP2
        ;                   0= GP2/T0CKI/COUT


; Ordine di precedenza delle funzioni dei PORT
; # | GP0  | GP1  | GP2  |  GP3  |
;---|------|------|------|-------|
; 1 | TRIS | TRIS | T0CKI|I/MCLR |
; 3 |   -  |   -  | TRIS |  -    |


; GPIO - Registro PORT
;----------------------
; al POR          '----xxxx'

; TRISGPIO - Direzione GPIO
; --------------------------
; al POR          '----1111'
DIRPORT    EQU   B'----1110'
         ;         |  |||||____ TRISGP0 in
         ;         |  ||||_____ TRISGP1 in
         ;         |  |||______ TRISGP2 in
         ;         |  ||_______ TRISGP3 solo in
         ;         |__|________ -