;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Assembly & C - Esercitazione 1Aw_5089
;                     Accendere un LED collegato al pin GP5.
;                     Il LED si accende all' arrivo della tensione
;                     di alimentazione e rimane acceso finch questa
;                      presente
;
;    PIC           :  12F508/509
;    Supporto      :  MPASM
;    Versione      :  1.0
;    Data          :  01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;--------------------------------------------------------------------
;
;  Impiego pin :
;  ----------------
;       12F508/509 @ 8 pin
;
;                  |\/|
;             Vdd -|1    8|- Vss
;             GP5 -|2    7|- GP0
;             GP4 -|3    6|- GP1
;        GP3/MCLR -|4    5|- GP2
;                  |______|
;
;    Vdd                1: ++
;    GP5/OSC1/CLKIN     2: Out  LED alla Vss (R in serie)
;    GP4/OSC2           3:
;    GP3/!MCLR/VPP      4:
;    GP2/T0CKI          5:
;    GP1/ICSPCLK        6:
;    GP0/ICSPDAT        7:
;    Vss                8: --
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;
;GPIO map
;|  5  |  4  |  3  |  2  |  1  |  0  |
;|-----|-----|-----|-----|-----|-----|
;| LED |     |     |     |     |     |
;
;#define    GPIO,GP0    ;
;#define    GPIO,GP1    ;
;#define    GPIO,GP2    ;
;#define    GPIO,GP3    ;
;#define    GPIO,GP4    ;
#define    LED  GPIO,GP5    ; LED tra pin 2 e Vss
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################
; scelta del processore
 #ifdef   __12F509
        LIST      p=12F509          ; Definizione del processore
        #include <p12F509.inc>
 #endif
 #ifdef  __12F508
        LIST      p=12F508          ; Definizione del processore
        #include <p12F508.inc>
 #endif

        radix     dec               ; radice decimale

        LIST      X = ON            ; espande macro

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; Oscillatore interno, no WDT, no CP, pin4=GP3
;
 __config  _IntRC_OSC & _WDT_OFF & _CP_OFF & _MCLRE_ON

;####################################################################
;====================================================================
;=                      LOCAL MACROS                                =
;====================================================================
; Comandi per il LED
 Accendi_LED   MACRO
        bsf     LED
               ENDM

;####################################################################


;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; movlw valore_calibrazione   prima istruzione intrinseca

; Reset Vector
        ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni al reset
        clrf    GPIO            ; preset GPIO latch a 0

; Assegna a GP5 la funzione di uscita digitale
; TRISGPIO        xx011111     GP5 out
        movlw   b'11011111'
        tris    GPIO


; accende LED portando a livello 1 il pin GP5
        Accendi_LED

; blocco - loop chiuso
        goto    $


;********************************************************************
; ===================================================================
; =                           THE END                               =
;====================================================================
;********************************************************************
; fine sorgente
        END

 PAGE
; testo di commento per documentazione
;********************************************************************
; ===================================================================
; =                       DOCUMENTAZIONE                            =
;====================================================================
;********************************************************************
; Opzioni CONFIG
;********************************************************************
;
; Oscillatore
; ---------------------------------------------
;_OSC_LP          ; osc. esterno LP con 18ms DRT
;_LP_OSC          ; alias
;_OSC_XT          ; osc. esterno XP con 18ms DRT
;_XT_OSC          ; alias
;_OSC_IntRC       ; osc. interno 4MHz con 1.125ms DRT
;_IntRC_OSC       ; alias
;_OSC_ExtRC       ; osc. esterno RC con 1.125ms DRT
;_ExtRC_OSC       ; alias

; Watchdog
; ---------------------------------------------
;_WDT_ON                abilitato
;_WDT_OFF               disabilitato

; Protezione della EEPROM
; ---------------------------------------------
;_CPD_ON                protezione abilitata
;_CPD_OFF               protezione disabilitata

; Pin MCLR
; ---------------------------------------------
;_MCLRE_ON              GP3/MCLR come MCLR
;_MCLRE_OFF             GP3/MCLR come GP3

;********************************************************************
;                          MEMORIA RAM                              *
;********************************************************************
; 12F508 un solo banco
; 07-1Fh   25 bytes
;
; 12F509 due banchi
; 07-0Fh (27-2Fh)  9 bytes accessibili da entrambi i banchi
; 10-1Fh          16 bytes accessibili solo dal Bank0
; 30-3Fh          16 bytes accessibili solo dal Bank1
; Switch dei banchi: STATUS,PA0


;********************************************************************
;                        PRINCIPALI SFR                             *
;********************************************************************
; SFR su un solo banco
;
;OPTION_REG - Options & TIMER0 - scrivibile con option
;------------------------------------------------------
 ; al POR          '11111111'
 OPTIONVAL   EQU  B'11010111'
         ;          1-------     GPWU disabilitato
         ;          -1------     GPPU disabilitato
         ;          --0-----     clock interno
         ;          ---1----     done
         ;          ----0---     prescaler al timer
         ;          -----111     1:256
 ;
         ; NOT_GPWU  b7 : enable wake-up pin on change
         ;                1= disabilitato
         ;                0= abilitato
         ; NOT_GPPU  b6 : Enable Weak Pull-ups bit
         ;                1= disabilitato
         ;                0= abilitato
         ; TOCS      b5 : 1= clock TMR0 esterno da GP2
         ;                0= clock interno
         ; TOSE      b4 : 1= GP2 fronte discendente (b5=1)
         ;                0= GP2 fronte in salita   (b5=1)
         ; PSA       b3 : 1= predivisore al Watchdog
         ;                0= predivisore a TMR0
         ; PS2/PS0   b2/b0 valore del predivisore
         ;                  Watchdog   Timer0
         ;           000 =  1/1        1/2
         ;           001 =  1/2        1/4
         ;           010 =  1/4        1/8
         ;           011 =  1/8        1/16
         ;           100 =  1/16       1/32
         ;           101 =  1/32       1/64
         ;           110 =  1/64       1/128
         ;           111 =  1/128      1/256



; OSCCAL - Calibrazione oscillatore interno
; ------------------------------------------
OSCCALDEF  EQU    B'00000000' ; valore intermedio
        ; CAL6:0    b7:1  : 01111 = Maximum frequency
        ;                   00000 = Center frequency
        ;                   10000 = Minimum frequency
        ; riservato b0


; Ordine di precedenza delle funzioni dei PORT
; # | GP0  | GP1  | GP2  |  GP3 | GP4  | GP5  |
;-----------------|------|------|-------------|
; 1 | TRIS | TRIS | T0CKI|I/MCLR| TRIS | TRIS |
; 3 |   -  |   -  | TRIS |  -   |   -  |   -  |


; GPIO - Registro GPIO
; ---------------------
; al POR          '----xxxx'

; TRISGPIO - Direzione GPIO
; --------------------------
; al POR          '--111111'
TRISValue  EQU   B'--011111'
         ;         ||||||||____ TRISGP0 in
         ;         |||||||_____ TRISGP1 in
         ;         ||||||______ TRISGP2 in
         ;         |||||_______ TRISGP3 solo in
         ;         ||||________ TRISGP4 in
         ;         |||_________ TRISGP5 out
         ;         ||__________ non usati