;********************************************************************
;--------------------------------------------------------------------
;
;    Titolo        :  Corso Assembly & C - Esercitazione 1Aw_519
;                     Accendere un LED collegato al pin GP5.
;                     Il LED si accende all' arrivo della tensione
;                     di alimentazione e rimane acceso finch questa
;                      presente

;    PIC           :  12F519
;    Supporto      :  MPASM
;    Versione      :  1.0
;    Data          :  01-05-2013
;    Ref. hardware :
;    Autore        :  afg
;
;--------------------------------------------------------------------
;
;  Impiego pin :
;  ----------------
;       12F519 @ 8 pin
;
;                  |\/|
;             Vdd -|1    8|- Vss
;             GP5 -|2    7|- GP0
;             GP4 -|3    6|- GP1
;        GP3/MCLR -|4    5|- GP2
;                  |______|
;
;    Vdd                1: ++
;    GP5/OSC1/CLKIN     2: Out  LED alla Vss (R in serie)
;    GP4/OSC2           3:
;    GP3/!MCLR/VPP      4:
;    GP2/T0CKI          5:
;    GP1/ICSPCLK        6:
;    GP0/ICSPDAT        7:
;    Vss                8: --
;
;********************************************************************
;====================================================================
;            DEFINIZIONE DI IMPIEGO DEI PORT
;====================================================================
;
;GPIO map
;|  5  |  4  |  3  |  2  |  1  |  0  |
;|-----|-----|-----|-----|-----|-----|
;| LED |     |     |     |     |     |
;
;#define    GPIO,GP0    ;
;#define    GPIO,GP1    ;
;#define    GPIO,GP2    ;
;#define    GPIO,GP3    ;
;#define    GPIO,GP4    ;
#define    LED  GPIO,GP5    ; LED tra pin e Vss
;
;********************************************************************
;####################################################################
;
;    Note :
;
;********************************************************************
;####################################################################

        LIST      p=12F519         ; Definizione del processore

        #include <p12F519.inc>

        radix     dec

;####################################################################
;====================================================================
;                          CONFIGURAZIONE                           =
;====================================================================
;
; Oscillatore interno, no WDT, no CP, pin4=GP3
;
 __config  _IntRC_OSC & _IOSCFS_4MHz & _WDTE_OFF & _CP_OFF & _CPDF_OFF & _MCLRE_OFF


;####################################################################
;====================================================================
;=                         MACRO LOCALI                             =
;====================================================================
Accendi_LED  MACRO
           bsf   LED     ; accende il LED
             ENDM

;####################################################################
;====================================================================
;=                         RESET ENTRY                              =
;====================================================================
; movlw valore_calibrazione   prima istruzione intrinseca

; Reset Vector
RESET_VECTOR   ORG     0x00

 ; calibrazione oscillatore interno
        movwf   OSCCAL


;####################################################################
;====================================================================
;=                        MAIN PROGRAM                              =
;====================================================================
MAIN:
; inizializzazioni dell' I/O al reset
        clrf    GPIO            ; preset GPIO latch a 0

; Assegna a GP5 la funzione di uscita digitale
; TRISGPIO        xx011111     GP5 out
        movlw   b'11011111'
        tris    GPIO

; accende LED portando a livello 1 il pin GP5
        Accendi_LED

; blocco - loop chiuso
        goto    $

;********************************************************************
;====================================================================
;=                            THE END                               =
;====================================================================
;********************************************************************
; fine sorgente
        END

 PAGE
; testo di commento per documentazione
;********************************************************************
; ===================================================================
; =                       DOCUMENTAZIONE                            =
;====================================================================
;********************************************************************
; Opzioni del CONFIG
;********************************************************************
;
; Oscillatore
; ---------------------------------------------
;_FOSC_LP         ; osc. esterno LP con 18ms DRT
;_LP_OSC          ; alias
;_FOSC_XT         ; osc. esterno XP con 18ms DRT
;_XT_OSC          ; alias
;_FOSC_INTRC      ; osc. interno con 1.125ms DRT
;_IntRC_OSC       ; alias
;_FOSC_EXTRC      ; osc. esterno RC con 1.125ms DRT
;_ExtRC_OSC       ; alias

; Frequenza oscillatore interno
; ---------------------------------------------
;_IOSCFS_4MHz     ; 4 MHz INTOSC
;_IOSCFS_8MHz     ; 8 MHz INTOSC

; Watchdog
; ---------------------------------------------
;_WDTE_ON         ; abilitato
;_WDTE_OFF        ; disabilitato

; Protezione della memoria programma
; ---------------------------------------------
;_CP_ON           ; protezione abilitata
;_CP_OFF          ; protezione disabilitata

; Pin MCLR
; ---------------------------------------------
;_MCLRE_ON        ; GP3/MCLR come MCLR
;_MCLRE_OFF       ; GP3/MCLR come GP3

; Protezione della EEPROM
; ---------------------------------------------
;_CPDF_ON         ; protezione abilitata
;_CPDF_OFF        ; protezione disabilitata

;********************************************************************
;                          MEMORIA RAM                              *
;********************************************************************
; Su due banchi
; 07-0Fh (27-2Fh)  9 bytes accessibili da entrambi i banchi
; 10-1Fh          16 bytes accessibili solo dal Bank0
; 30-3Fh          16 bytes accessibili solo dal Bank1
; Switch dei banchi: STATUS,PA0

;********************************************************************
;                        PRINCIPALI SFR                             *
;********************************************************************
; Su due banchi
; STATUS, INDF, PCL, FSR accessibili da entrambi i banchi
; GPIO, OSCCAL, TMR0     accessibili solo dal Bank0
; EECON, EEDATA, EEADR   accessibili solo dal Bank1

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 0
;
;OPTION_REG - Options & TIMER0 - scrivibile con option
;------------------------------------------------------
 ; al POR          '11111111'
 OPTIONVAL   EQU  B'11010111'
         ;          1-------     GPWU disabilitato
         ;          -1------     GPPU disabilitato
         ;          --0-----     clock interno - GP2 disponibile
         ;          ---1----     falling
         ;          ----0---     prescaler al timer
         ;          -----111     1:256
 ;
         ; NOT_GPWU  b7 : enable wake-up pin on change
         ;                1= disabilitato
         ;                0= abilitato
         ; NOT_GPPU  b6 : Enable Weak Pull-ups bit
         ;                1= disabilitato
         ;                0= abilitato
         ; TOCS      b5 : 1= clock TMR0 esterno da GP2
         ;                0= clock interno
         ; TOSE      b4 : 1= GP2 fronte discendente (b5=1)
         ;                0= GP2 fronte in salita   (b5=1)
         ; PSA       b3 : 1= predivisore al Watchdog
         ;                0= predivisore a TMR0
         ; PS2/PS0   b2/b0 valore del predivisore
         ;                  Watchdog   Timer0
         ;           000 =  1/1        1/2
         ;           001 =  1/2        1/4
         ;           010 =  1/4        1/8
         ;           011 =  1/8        1/16
         ;           100 =  1/16       1/32
         ;           101 =  1/32       1/64
         ;           110 =  1/64       1/128
         ;           111 =  1/128      1/256


; OSCCAL - Calibrazione oscillatore interno - bank 0
; ---------------------------------------------------
OSCCALDEF  EQU    B'00000000' ; valore intermedio
        ; CAL6:0  b7:1 01111 = Maximum frequency
        ;              00000 = Center frequency
        ;              10000 = Minimum frequency
        ; res.    b0           reserved


; Ordine di precedenza delle funzioni dei PORT
; # | GP0  | GP1  | GP2  |  GP3 | GP4  | GP5  |
;-----------------|------|------|-------------|
; 1 | TRIS | TRIS | T0CKI|I/MCLR| TRIS | TRIS |
; 3 |   -  |   -  | TRIS |  -   |   -  |   -  |


; GPIO - Registro GPIO
; ---------------------
; al POR          '----xxxx'

; TRISGPIO - Direzione GPIO
; --------------------------
; al POR          '--111111'
TRISValue  EQU   B'--011111'
         ;         ||||||||____ TRISGP0 in
         ;         |||||||_____ TRISGP1 in
         ;         ||||||______ TRISGP2 in
         ;         |||||_______ TRISGP3 solo in
         ;         ||||________ TRISGP4 in
         ;         |||_________ TRISGP5 out
         ;         ||__________ non usati

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 1
;
; EECON - Controllo EEPROM - bank 1
; ----------------------------------
        ; reserved b7:5-------: reserved
        ; FREE     b4 --------: forza cancellazione
        ; WRERR    b3 --------: errore reset
        ; WREN     b2 --------: abilita scrittura
        ; WR       b1 --------: scrittura
        ; RD       b0 --------: lettura


; EEDATA - Registro dati EEPROM - bank 1
; ---------------------------------------

; EEADR - Registro indirizzo EEPROM - bank 1
; --------------------------------------------