;********************************************************************
; 16F526
; Documentazione per template e sorgenti asm
;--------------------------------------------------------------------
;  Pinout
;  ----------------
;       12F526 @ 14 pin
;
;                  |\/|
;             Vdd -|1   14|- Vss
;             RB5 -|2   13|- RB0
;             RB4 -|3   12|- RB1
;        RB3/MCLR -|4   11|- RB22
;             RC5 -|5   10|- RC0
;             RC4 -|6    9|- RC1
;             RC3 -|7    8|- RC2
;                  |______|
;
;    Vdd                  1: ++
;    RB5/OSC1/CLKIN       2:
;    RB4/OSC2/CLKOUT      3:
;    RB3/!MCLR/VPP        4:
;    RC5/T0CKI            5:
;    RC4/C2OUT            6:
;    RC3                  7:
;    RC2/CVref            8:
;    RC1/C2IN-            9:
;    RC0/C2IN+           10:
;    RB2/C1OUT/AN2       11:
;    RB1/C1IN-/AN1/ICSPC 12:
;    RB0/C1IN+/AN0/ICSPD 13:
;    Vss                 14: --

;********************************************************************
;====================================================================
;=                         CONFIG e SFR                             =
;====================================================================
;********************************************************************
;                         Opzioni CONFIG
;********************************************************************
;
; Oscillatore
; ---------------------------------------------
;_FOSC_LP         ; osc. esterno LP con 18ms DRT
;_LP_OSC          ; alias
;_FOSC_XT         ; osc. esterno XP con 18ms DRT
;_XT_OSC          ; alias
;_FOSC_INTRC      ; osc. interno con 1.125ms DRT
;_IntRC_OSC       ; alias
;_FOSC_EXTRC      ; osc. esterno RC con 1.125ms DRT
;_ExtRC_OSC       ; alias

;  Frequenza oscillatore interno
; ---------------------------------------------
;_IOSCFS_4MHz     ; 4 MHz INTOSC
;_IOSCFS_8MHz     ; 8 MHz INTOSC

; Watchdog
; ---------------------------------------------
;_WDTE_ON         ; abilitato
;_WDTE_OFF        ; disabilitato

; Protezione della memoria programma
; ---------------------------------------------
;_CP_ON           ; protezione abilitata
;_CP_OFF          ; protezione disabilitata

; Pin MCLR
; ---------------------------------------------
;_MCLRE_ON        ; GP3/MCLR come MCLR
;_MCLRE_OFF       ; GP3/MCLR come GP3

; Protezione della EEPROM
; ---------------------------------------------
;_CPDF_ON         ; protezione abilitata
;_CPDF_OFF        ; protezione disabilitata


;********************************************************************
;                        PRINCIPALI SFR                             *
;********************************************************************
; SFR su due banchi
; STATUS, INDF, PCL, FSR accessibili da entrambi i banchi
; GPIO, OSCCAL, TMR0     accessibili solo dal Bank0
; EECON, EEDATA, EEADR   accessibili solo dal Bank1

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 0
;
;OPTION_REG - Options & TIMER0 - scrivibile con option
;------------------------------------------------------
; al POR          '11111111'
OPTIONVAL   EQU  B'11010111'
         ;          1-------     GPWU disabilitato
         ;          -1------     GPPU disabilitato
         ;          --0-----     clock interno
         ;          ---1----     falling
         ;          ----0---     prescaler al timer
         ;          -----111     1:256
 ;
         ; NOT_GPWU  b7 : enable wake-up pin on change
         ;                1= disabilitato
         ;                0= abilitato
         ; NOT_GPPU  b6 : Enable Weak Pull-ups bit
         ;                1= disabilitato
         ;                0= abilitato
         ; TOCS      b5 : 1= clock TMR0 esterno da GP2
         ;                0= clock interno
         ; TOSE      b4 : 1= GP2 fronte discendente (b5=1)
         ;                0= GP2 fronte in salita   (b5=1)
         ; PSA       b3 : 1= predivisore al Watchdog
         ;                0= predivisore a TMR0
         ; PS2/PS0   b2/b0 valore del predivisore
         ;                  Watchdog   Timer0
         ;           000 =  1/1        1/2
         ;           001 =  1/2        1/4
         ;           010 =  1/4        1/8
         ;           011 =  1/8        1/16
         ;           100 =  1/16       1/32
         ;           101 =  1/32       1/64
         ;           110 =  1/64       1/128
         ;           111 =  1/128      1/256


; OSCCAL - Calibrazione oscillatore interno - bank 0
; ---------------------------------------------------
OSCCALDEF  EQU    B'00000000' ; valore intermedio
        ; CAL6:0    b7:1  : 01111 = Maximum frequency
        ;                   00000 = Center frequency
        ;                   10000 = Minimum frequency
        ; riservato b0


; Ordine di precedenza delle funzioni dei PORT
; # | GP0  | GP1  | GP2  |  GP3 | GP4  | GP5  |
;-----------------|------|------|-------------|
; 1 | TRIS | TRIS | T0CKI|I/MCLR| TRIS | TRIS |
; 3 |   -  |   -  | TRIS |  -   |   -  |   -  |


; GPIO - Registro GPIO
; ---------------------
; al POR          '----xxxx'

; TRISGPIO - Direzione GPIO
; --------------------------
; al POR          '--111111'
DIRPORT    EQU   B'--011111'
         ;         ||||||||____ TRISGP0 in
         ;         |||||||_____ TRISGP1 in
         ;         ||||||______ TRISGP2 in
         ;         |||||_______ TRISGP3 solo in
         ;         ||||________ TRISGP4 in
         ;         |||_________ TRISGP5 out
         ;         ||__________ non usati

;+++++++++++++++++++++++++++++++++++++++++++++++++++++
; Registri in Bank 1
;
;EECON - Controllo EEPROM - bank 1
;----------------------------------
        ; reserved b7:5-------: reserved
        ; FREE     b4 --------: forza cancellazione
        ; WRERR    b3 --------: errore reset
        ; WREN     b2 --------: abilita scrittura
        ; WR       b1 --------: scrittura
        ; RD       b0 --------: lettura


; EEDATA - Registro dati EEPROM - bank 1
; ---------------------------------------

; EEADR - Registro indirizzo EEPROM - bank 1
; -------------------------------------------